@@ -34,20 +34,20 @@ parseURL <- function(x, use = "neotoma", all_data = FALSE, ...) { # nolint
   }
   
   baseurl <- switch(use,
-                    "dev" = "https://api-dev.neotomadb.org/v2.0/",
+                    "dev" = "http://api-dev.neotomadb.org/v2.0/",
                     "neotoma" = "https://api.neotomadb.org/v2.0/",
                     "local" = "http://localhost:3005/v2.0/",
                     use)
   
   query <- list(...)
-
+  
   if (all_data == FALSE) {
     try(
       response <- httr::GET(paste0(baseurl, x),
                             add_headers("User-Agent" = "neotoma2 R package"),
                             query = query)
     )
-
+    
     if (inherits(response, "try-error")) {
       # Handle the SSL error
       error_message <- conditionMessage(response)
@@ -66,9 +66,10 @@ parseURL <- function(x, use = "neotoma", all_data = FALSE, ...) { # nolint
       body <- parsebody(x, all_data=FALSE, ...)
       try(
         response <- httr::POST(new_url,
-                             body = body,
-                             add_headers("User-Agent" = "neotoma2 R package"),
-                             httr::content_type("application/json"))
+                               body = body,
+                               add_headers("User-Agent" = "neotoma2 R package"),
+                               httr::content_type("application/json")
+      )
       )
       if (inherits(response, "try-error")) {
         # Handle the SSL error
@@ -109,15 +110,14 @@ parseURL <- function(x, use = "neotoma", all_data = FALSE, ...) { # nolint
     if ("limit" %in% names(query)) {
       stop("You cannot use the limit parameter when all_data is TRUE")
     }
-    
     query$offset <- 0
-    query$limit <- 50
+    query$limit <- 2000
     ql <- query$limit
     
     try(
       response <- httr::GET(paste0(baseurl, x),
-                          add_headers("User-Agent" = "neotoma2 R package"),
-                          query = query)
+                            add_headers("User-Agent" = "neotoma2 R package"),
+                            query = query)
     )
     
     if (inherits(response, "try-error")) {
@@ -129,74 +129,105 @@ parseURL <- function(x, use = "neotoma", all_data = FALSE, ...) { # nolint
         stop("SSL certificate error:", error_message, "\n Please contact the Neotoma Team")
       }
     }
-
-    if (response$status_code == 414 | nchar(response$url) > 2000) {
-      # Function with Post (Use this once server issue is resolved)
-      args <- x
-      new_url <- newURL(baseurl, args, ...)
-      body <- parsebody(args, all_data, ...)
-      body <- jsonlite::fromJSON(body)
-      if('siteid' %in% names(body)){
-        ids_nos <- as.numeric(stringr::str_extract_all(body$siteid,
-                                                       "[0-9.]+")[[1]])}
-      if('datasetid' %in% names(body)){
-        ids_nos <- as.numeric(stringr::str_extract_all(body$datasetid,
-                                                       "[0-9.]+")[[1]])
-      }
-      seq_chunk <- split(ids_nos,
-                         ceiling(seq_along(ids_nos) / query$limit))
-      
-      responses <- c()
-      
-      for (sequ in seq_chunk) {
-        body2 <- list()
-        body2 <- body
-        names(body2) <- names(body)
-        
-        if('siteid' %in% names(body)){
-          body2$siteid <- paste0(sequ, collapse = ",")
-        }
-        if('datasetid' %in% names(body)){
-          body2$datasetid <- paste0(sequ, collapse = ",")
-        }
-        body2$limit <- ql # Refer to the previous variable rather than hardcoding
-        body2 <- jsonlite::toJSON(body2, auto_unbox = TRUE)
+    if (response$status_code == 414 & nchar(response$url) > 2000) {
+      if (any(!(c('siteid', 'datasetid') %in% names(body)))) {
+        # The 414 error is a URL that is too long. This is a lazy way to manage
+        # the choice between a POST and GET call.
+        # Function with POST (Use this once server issue is resolved)
+        args <- x
+        new_url <- newURL(baseurl, args, ...)
+        ql <- query$limit
+        body <- parsebody(args, all_data=FALSE, limit=2000, ...) #lazy fix. think of other ways to handle long urls
+        #body <- jsonlite::toJSON(body, auto_unbox = TRUE) #, pretty = TRUE
         try(
           response <- httr::POST(new_url,
-                               body = body2,
-                               add_headers("User-Agent" = "neotoma2 R package"),
-                               httr::content_type("application/json"))
+                                 body = body,
+                                 encode = 'json',
+                                 add_headers("User-Agent" = "neotoma2 R package"),
+                                 httr::content_type("application/json"),
+                                 httr::verbose())
         )
-        if (inherits(response, "try-error")) {
-          # Handle the SSL error
-          error_message <- conditionMessage(response)
-          
-          if (grepl("SSL certificate", error_message, ignore.case = TRUE)) {
-            # Handle SSL certificate-related errors
-            stop("SSL certificate error:", error_message, "\n Please contact the Neotoma Team")
-          }
-        }
         stop_for_status(response,
                         task = "Could not connect to the Neotoma API.
                     Check that the path is valid, and check the current
                      status of the Neotoma API services at
                       http://data.neotomadb.org")
         
-        result <- jsonlite::fromJSON(httr::content(response, as = "text"),
-                                     flatten = FALSE,
-                                     simplifyVector = FALSE)
+        if (response$status_code == 200) {
+          result <- jsonlite::fromJSON(httr::content(response, as = "text"),
+                                       flatten = FALSE,
+                                       simplifyVector = FALSE)
+          result <- cleanNull(result)
+        }
         
-        responses <- c(responses, cleanNull(result)$data)
+      } else {
+        args <- x
+        new_url <- newURL(baseurl, args, ...)
+        body <- parsebody(args, all_data, ...)
+        body <- jsonlite::fromJSON(body)
+        if('siteid' %in% names(body)){
+          ids_nos <- as.numeric(stringr::str_extract_all(body$siteid,
+                                                         "[0-9.]+")[[1]])
+        }
+        if('datasetid' %in% names(body)){
+          ids_nos <- as.numeric(stringr::str_extract_all(body$datasetid,
+                                                         "[0-9.]+")[[1]])
+        }
+        query$limit <-50
+        seq_chunk <- split(ids_nos,
+                           ceiling(seq_along(ids_nos) / query$limit))
+        
+        for (sequ in seq_chunk) {
+          body2 <- list()
+          body2 <- body
+          names(body2) <- names(body)
+          
+          if('siteid' %in% names(body)){
+            body2$siteid <- paste0(sequ, collapse = ",")
+          }
+          if('datasetid' %in% names(body)){
+            body2$datasetid <- paste0(sequ, collapse = ",")
+          }
+          body2$limit <- ql # Refer to the previous variable rather than hardcoding
+          body2 <- jsonlite::toJSON(body2, auto_unbox = TRUE)
+          try(
+            response <- httr::POST(new_url,
+                                   body = body2,
+                                   add_headers("User-Agent" = "neotoma2 R package"),
+                                   httr::content_type("application/json"))
+          )
+          if (inherits(response, "try-error")) {
+            # Handle the SSL error
+            error_message <- conditionMessage(response)
+            
+            if (grepl("SSL certificate", error_message, ignore.case = TRUE)) {
+              # Handle SSL certificate-related errors
+              stop("SSL certificate error:", error_message, "\n Please contact the Neotoma Team")
+            }
+          }
+          stop_for_status(response,
+                          task = "Could not connect to the Neotoma API.
+                        Check that the path is valid, and check the current
+                         status of the Neotoma API services at
+                          http://data.neotomadb.org")
+          
+          result <- jsonlite::fromJSON(httr::content(response, as = "text"),
+                                       flatten = FALSE,
+                                       simplifyVector = FALSE)
+          
+          responses <- c(responses, cleanNull(result)$data)
+          result$data <- responses
+        }
       }
-      result$data <- responses
+      
       return(result)
     } else {
       responses <- c()
       while (TRUE) {
         try(
-        response <- httr::GET(paste0(baseurl, x),
-                              add_headers("User-Agent" = "neotoma2 R package"),
-                              query = query)
+          response <- httr::GET(paste0(baseurl, x),
+                                add_headers("User-Agent" = "neotoma2 R package"),
+                                query = query)
         )
         if (inherits(response, "try-error")) {
           # Handle the SSL error
@@ -252,6 +283,9 @@ newURL <- function(baseurl, args, ...) {
   } else if (grepl("downloads", args)) {
     new_url <- paste0(baseurl, "data/downloads")
     params <- stringr::str_remove_all(args, "data/downloads")
+  } else {
+    new_url <- baseurl
+    params <- args
   }
   return(new_url)
 }
\ No newline at end of file
